# Librem 5 Package Information Tool

This application reads and displays information about the installed PureOS
packages on the Librem 5 phone.

It assumes that a corresponding `deb-src` line is given for each `deb` line in
the `/etc/apt/sources.list` file and that `apt update` has been run. This will
have placed files in `/var/lib/apt/lists` that contain information about the
sources for each package. The application will run without these files but will
be unable to show any information about sources.

## Building the Application

The application can be configured using the Meson and Ninja build systems.
To configure the build, run `meson` and specify the source and build
directories:

``` bash
meson . _build
```

Build the application using `ninja`, passing the build directory as an
argument so that the build occurs within that directory:

``` bash
ninja -C _build
```

The default rule is to build the application.

Finally, install the application to a standard location:

``` bash
ninja -C _build install
```

Installing to a standard system location will generally require `sudo` to be
used.

## Creating Standalone Information

The `tools` directory of the source repository contains two scripts that can
be used to create a standalone collection of pages for publishing.

The `librem5-mount-rootfs.py` tool is used to mount an uncompressed disk
image for the phone and update its internal `/etc/apt/sources.list` file with
source links. For example, it can be run in the following way to mount the
`/tmp/librem5.img` disk image at `/tmp/mnt` before updating its sources:

``` bash
mkdir /tmp/mnt
sudo tools/librem5-mount-rootfs.py /tmp/librem5.img /tmp/mnt
```

Once this has finished, it will prompt you to run the `dpkg-status-summary.py`
script with appropriate arguments like these:

``` bash
tools/dpkg-status-summary.py -d Evergreen /tmp/mnt /tmp/output
```

In this case, the script will create a set of pages for the Evergreen release
based on the contents of the disk image mounted at `/tmp/mnt` and write them
to the `/tmp/output` directory. It will also include copyright and license
files, as well as provide links to the sources and metadata files in the apt
repository. The `-d` option also downloads sources and metadata files for
future reference, making them available for inspection or auditing.

The output directory can then be copied to a server for publication.

## License

The source code is licensed under the GNU General Public License version 3 or
later. See the COPYING file for more information about this license. A summary
of the copyright and license is given below:

```
Copyright (C) 2019 Purism SPC
SPDX-License-Identifier: GPL-3.0+
Author: David Boddie <david.boddie@puri.sm>
```
